bayespy.inference.vmp.nodes.categorical_markov_chain.CategoricalMarkovChainDistribution.random
==============================================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.categorical_markov_chain

.. automethod:: CategoricalMarkovChainDistribution.random